@@ -1,6 +1,7 @@
-use solana_sdk::instruction::Instruction;
-use solana_sdk::pubkey::Pubkey;
-use spl_memo::id;
+use {
+    solana_sdk::{instruction::Instruction, pubkey::Pubkey},
+    spl_memo::id,
+};
 
 pub trait WithMemo {
     fn with_memo<T: AsRef<str>>(self, memo: Option<T>) -> Self;
