@@ -1,13 +1,13 @@
 use {
     solana_cli::cli::{process_command, CliCommand, CliConfig},
     solana_client::rpc_client::RpcClient,
-    solana_core::test_validator::TestValidator,
     solana_faucet::faucet::run_local_faucet,
     solana_sdk::{
         commitment_config::CommitmentConfig,
         signature::{Keypair, Signer},
     },
     solana_streamer::socket::SocketAddrSpace,
+    solana_test_validator::TestValidator,
 };
 
 #[test]
